contentpublishingsrv/contentharvester/contentharvesterswiplugin/inc/chswiplugin.h
branchRCL_3
changeset 8 d0529222e3f0
parent 3 ff572005ac23
child 22 1b207dd38b72
--- a/contentpublishingsrv/contentharvester/contentharvesterswiplugin/inc/chswiplugin.h	Tue Feb 02 00:23:10 2010 +0200
+++ b/contentpublishingsrv/contentharvester/contentharvesterswiplugin/inc/chswiplugin.h	Fri Feb 19 23:07:29 2010 +0200
@@ -94,10 +94,10 @@
 	/** 
 	 * Removes single widget.
 	 * @param aType Widget type.
 	 * @param aContentId Widget UID.
 	 */
 	void RemoveWidgetL( const TDesC& aType, 
-        const TDesC& aContentId );
+        const TDesC& aPublisherId );
 	
 
 private:
@@ -94,10 +94,10 @@
 	 * Removes single widget.
 	 * @param aType Widget type.
-	 * @param aContentId Widget UID.
+	 * @param aPublisherId Widget UID.
 	 */
 	void RemoveWidgetL( const TDesC& aType, 